@@ -29,8 +29,7 @@ class Experimento:
                  tamanio_intervalo_para_promedio=100, genera_matriz_recurrencia=False, regiones_preferidas=None,
                  genera_regiones_preferidas=True, distancia_max_para_volumenes=24, division_de_dist_max=2):
         self.nombre_archivo = nombre_archivo
-        print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:",
-              type(self.nombre_archivo))
+        print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
         self.dimension_caja = dimension_caja
         self.cantidad_filas = cantidad_filas
         self.cantidad_columnas = cantidad_columnas
@@ -241,15 +240,7 @@ class Experimento:
         if genera_matriz_recurrencia is True:
             self.calcula_matrices_de_recurrencia()
         if genera_regiones_preferidas is True:
-            matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
-            self.matriz_cuadriculada_solo_regiones_preferidas = \
-                rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
-            self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-                rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
-            self.matriz_cuadriculada_solo_regiones_preferidas =\
-                np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
-            self.matriz_cuadriculada_solo_regiones_no_preferidas =\
-                np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+            self.calcula_matrices_regiones_preferidas()
 
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
@@ -486,57 +477,12 @@ class Experimento:
 
             self.matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
 
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="visitas_regiones",
+                                       datos=self.matriz_cuadriculada.flatten())
+
         print(self.matriz_cuadriculada)
 
-    def genera_matriz_cuadriculada_con_regiones_preferidas(self):
-        matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
-        self.visitas_regiones_preferidas = matriz_cuadriculada_plana[self.regiones_preferidas]
-        self.visitas_regiones_no_preferidas = np.delete(matriz_cuadriculada_plana, self.regiones_preferidas)
-
-        resultado_visitas_regiones_preferidas = sum(self.visitas_regiones_preferidas)
-        resultado_visitas_regiones_no_preferidas = sum(self.visitas_regiones_no_preferidas)
-
-        arreglo_regiones_preferidas = resultado_visitas_regiones_no_preferidas * np.ones(len(matriz_cuadriculada_plana))
-        arreglo_regiones_preferidas[self.regiones_preferidas] = resultado_visitas_regiones_preferidas
-
-        self.matriz_cuadriculada_regiones_preferidas = \
-            np.reshape(arreglo_regiones_preferidas, (self.cantidad_filas, self.cantidad_columnas))
-
-        self.matriz_cuadriculada_regiones_preferidas = np.flipud(self.matriz_cuadriculada_regiones_preferidas)
-
-    def genera_matriz_cuadriculada_solo_regiones_preferidas(self):
-        matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
-        self.visitas_regiones_preferidas = matriz_cuadriculada_plana[self.regiones_preferidas]
-
-        resultado_visitas_regiones_preferidas = sum(self.visitas_regiones_preferidas)
-
-        arreglo_regiones_preferidas = np.zeros(len(matriz_cuadriculada_plana))
-        arreglo_regiones_preferidas[self.regiones_preferidas] = resultado_visitas_regiones_preferidas
-
-        self.matriz_cuadriculada_solo_regiones_preferidas = \
-            np.reshape(arreglo_regiones_preferidas, (self.cantidad_filas, self.cantidad_columnas))
-
-        self.matriz_cuadriculada_solo_regiones_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
-
-        print("Matriz cuadriculada, solo regiones preferidas", self.matriz_cuadriculada_solo_regiones_preferidas)
-
-    def genera_matriz_cuadriculada_solo_regiones_no_preferidas(self):
-        matriz_cuadriculada_plana = np.flipud(self.matriz_cuadriculada).flatten()
-        self.visitas_regiones_preferidas = matriz_cuadriculada_plana[self.regiones_preferidas]
-        self.visitas_regiones_no_preferidas = np.delete(matriz_cuadriculada_plana, self.regiones_preferidas)
-
-        resultado_visitas_regiones_no_preferidas = sum(self.visitas_regiones_no_preferidas)
-
-        arreglo_regiones_no_preferidas = resultado_visitas_regiones_no_preferidas * np.ones(len(matriz_cuadriculada_plana))
-        arreglo_regiones_no_preferidas[self.regiones_preferidas] = 0
-
-        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-            np.reshape(arreglo_regiones_no_preferidas, (self.cantidad_filas, self.cantidad_columnas))
-
-        self.matriz_cuadriculada_solo_regiones_no_preferidas = np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
-
-        print("Matriz cuadriculada, solo regiones no preferidas", self.matriz_cuadriculada_solo_regiones_no_preferidas)
-
     def calcula_matrices_de_recurrencia(self):
 
         self.obtener_indice_regiones_objeto()
@@ -584,6 +530,27 @@ class Experimento:
                         self.matriz_recurrencia_objeto_4[i][j] = 1
                         self.matriz_recurrencia_combinada[i][j] = 4
 
+    def calcula_matrices_regiones_preferidas(self):
+        matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
+
+        self.matriz_cuadriculada_solo_regiones_preferidas = \
+            rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
+        self.matriz_cuadriculada_solo_regiones_preferidas = \
+            np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
+
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="visitas_regiones_preferidas",
+                                       datos=self.matriz_cuadriculada_solo_regiones_preferidas.flatten())
+
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
+
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="visitas_regiones_no_preferidas",
+                                       datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
+
     def calcula_alturas_volumenes_circulares_objetos_relevantes(self, tamanio=24, divisiones=2, tipo="cilindros"):
         longitud_movimientos = len(self.posiciones_x)
         valor_min_divivido = int(tamanio / divisiones)
